var searchData=
[
  ['d',['d',['../structlpi.html#a411cab0868ee86526ec41e53d68e15ce',1,'lpi::d()'],['../structnnai.html#a680e2d98ab08ebed90cad737df5dab5d',1,'nnai::d()'],['../structnnpi.html#a4a873a1a84656baa4e02b592ad8b000c',1,'nnpi::d()']]],
  ['d_5fname',['d_name',['../structdirent.html#a1450b4488b7067c7dc9d627b61fd4aa1',1,'dirent']]],
  ['data',['data',['../structht__bucket.html#a6eddd03a72cdb1e3ede43b1d746efabe',1,'ht_bucket::data()'],['../structdirent.html#a6ec995059bf4370c93292745f7da4b13',1,'dirent::data()'],['../structswig__lua__rawdata.html#acbba29d10dcd1b96ba3b8d255b777749',1,'swig_lua_rawdata::data()']]],
  ['db',['db',['../structPLStream.html#a5b485e23de946ddaae43b13a71d120a2',1,'PLStream']]],
  ['dcast',['dcast',['../structswig__type__info.html#a07df4bedf85be77b23756b531b60e0dd',1,'swig_type_info']]],
  ['debug',['debug',['../structPLStream.html#a5083e76d7de0c5588dcb018bc2a82a37',1,'PLStream::debug()'],['../pdfutils_8c.html#ac3e1795766a80ec63b157951b4b9a7d4',1,'debug():&#160;pdfutils.c']]],
  ['declare_5foctave_5fallocator',['DECLARE_OCTAVE_ALLOCATOR',['../classoctave__swig__ref.html#a72e925362835c43be262e4cfaf616dc1',1,'octave_swig_ref::DECLARE_OCTAVE_ALLOCATOR()'],['../classoctave__swig__packed.html#aa238bbb14ac6ff2139e300a78faa871b',1,'octave_swig_packed::DECLARE_OCTAVE_ALLOCATOR()']]],
  ['declare_5fov_5ftypeid_5ffunctions_5fand_5fdata',['DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA',['../classoctave__swig__ref.html#ab71cb80e748fd244ad22e1ca10173408',1,'octave_swig_ref::DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA()'],['../classoctave__swig__packed.html#ae34643b7178a4835df5f4e5af61dce9f',1,'octave_swig_packed::DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA()']]],
  ['defaultfamilylookup',['defaultFamilyLookup',['../cairo_8c.html#a736736436b0cd48c0634f4b6d24281dc',1,'cairo.c']]],
  ['del',['del',['../structpattern.html#ac397895cd856f8cd427aced26ecabe64',1,'pattern']]],
  ['delargs',['delargs',['../structSwigPyClientData.html#a9cb4b9b02743d09dbe216f304e2b7df0',1,'SwigPyClientData']]],
  ['deletedata',['deleteData',['../structCommand.html#af5085ae0b6dca11a1b532731b2f54d7b',1,'Command']]],
  ['deleteproc',['deleteProc',['../structCommand.html#a8a2efb8447e4e31c6272bd7a53aa4b99',1,'Command']]],
  ['delta',['delta',['../structPLStream.html#aab6220efc877149ddaad3b45ea6cc9f7',1,'PLStream']]],
  ['depth',['depth',['../structTkwDisplay.html#a9426efee240bc4a860ee9331a1b2c537',1,'TkwDisplay::depth()'],['../structXwDisplay.html#a56193de1c93773eafd82499cd1b00717',1,'XwDisplay::depth()']]],
  ['desc',['desc',['../structcdImageStruct.html#a0e1ec004c6a0169c15ae3e029db44a86',1,'cdImageStruct::desc()'],['../structplplot_1_1__N1.html#af0534204dc57ea02028dbd2b9060e591',1,'plplot::_N1::desc()'],['../structPLOptionTable.html#a911b32327a6078131c7810248c0f02cc',1,'PLOptionTable::desc()']]],
  ['destroy',['destroy',['../structSwigPyClientData.html#a1c4e62712f23db599e85e24e14818d59',1,'SwigPyClientData']]],
  ['destroyed',['destroyed',['../structoctave__swig__type_1_1cpp__ptr.html#aa26dc33d9fabfdafd2ff3fb988c4a21b',1,'octave_swig_type::cpp_ptr']]],
  ['destructor',['destructor',['../structswig__lua__class.html#ae7029d37913cf77df8f5c473c5cb43fe',1,'swig_lua_class::destructor()'],['../structswig__octave__class.html#a5e1ac4d7d832f631bc2001bfceeb374b',1,'swig_octave_class::destructor()']]],
  ['dev',['dev',['../structPLStream.html#abf8a6d71f35aeb854e3c75f5ed4f7679',1,'PLStream']]],
  ['dev_5f2005_5fheader',['dev_2005_header',['../plmetafile_8c.html#a355ad03ff95e155e9ef4654d7e15bb65',1,'plmetafile.c']]],
  ['dev_5farc',['dev_arc',['../structPLStream.html#a263a03b7f7481ecf73b47b50821d3006',1,'PLStream']]],
  ['dev_5fclear',['dev_clear',['../structPLStream.html#a5ffd0f763c8d12a0912ebc4355377329',1,'PLStream']]],
  ['dev_5fcompression',['dev_compression',['../structPLStream.html#a0b1b2bd10b03c184910e90aac79dddce',1,'PLStream']]],
  ['dev_5fdash',['dev_dash',['../structPLStream.html#a537ff4fef08a7f0978ac8f285739b54d',1,'PLStream']]],
  ['dev_5fdata',['dev_data',['../structPLStream.html#a64a27bd343528519bc7b9172ac9ae43b',1,'PLStream']]],
  ['dev_5fdi',['dev_di',['../structPLStream.html#ae84e24623a23d971c07e914557276808',1,'PLStream']]],
  ['dev_5feofill',['dev_eofill',['../structPLStream.html#ae43fbab5ba68a7c71f4cf5385178b2ff',1,'PLStream']]],
  ['dev_5ffastimg',['dev_fastimg',['../structPLStream.html#a7055c5f16dfa3de7f6c70fe69f846360',1,'PLStream']]],
  ['dev_5ffile_5fapp',['dev_file_app',['../structdev__entry.html#a1b3998791678ca6836eee87972dbd1a9',1,'dev_entry']]],
  ['dev_5ffill0',['dev_fill0',['../structPLStream.html#a36447d5d3f5bc8e6859c0b39308e4d6a',1,'PLStream']]],
  ['dev_5ffill1',['dev_fill1',['../structPLStream.html#acb765112b653f0c3bf7e9fd716d2daed',1,'PLStream']]],
  ['dev_5fflush',['dev_flush',['../structPLStream.html#ad906fcb4939128aac6738460716b28ac',1,'PLStream']]],
  ['dev_5fgradient',['dev_gradient',['../structPLStream.html#a753dd576c21893565997c66aa8d20b29',1,'PLStream']]],
  ['dev_5fhrshsym',['dev_hrshsym',['../structPLStream.html#a3d7a7ea09e1f39e922122ab6a8837f71',1,'PLStream']]],
  ['dev_5finitialized',['dev_initialized',['../structPLStream.html#a8c7933270949485ebbfe541d7bf45a06',1,'PLStream']]],
  ['dev_5fix',['dev_ix',['../structPLStream.html#a980c6538d17d90c388a88453546fc663',1,'PLStream']]],
  ['dev_5fiy',['dev_iy',['../structPLStream.html#a95520c10ded8c43651b5757cb7ca15c0',1,'PLStream']]],
  ['dev_5fmem_5falpha',['dev_mem_alpha',['../structPLStream.html#ab992021872cb743f34265ca2bd9388eb',1,'PLStream']]],
  ['dev_5fmenu_5flong',['dev_menu_long',['../structdev__entry.html#a47d1514de9a4d8519c0ee45bc6e62193',1,'dev_entry']]],
  ['dev_5fmenu_5fshort',['dev_menu_short',['../structdev__entry.html#a8504d919ebc6d33e0401f09721a5e056',1,'dev_entry']]],
  ['dev_5fminor',['dev_minor',['../structPLStream.html#a8577d7d860e6d7cc45f33c28c06263c0',1,'PLStream']]],
  ['dev_5fmodeset',['dev_modeset',['../structPLStream.html#a4b68f6f1f7a47daa793141fbbea35470',1,'PLStream']]],
  ['dev_5fname',['dev_name',['../structdev__entry.html#ab6060419382f71a0f13e9df4534dcd1d',1,'dev_entry']]],
  ['dev_5fnpts',['dev_npts',['../structPLStream.html#a47b274adf40a432cf4e95b4a54672199',1,'PLStream']]],
  ['dev_5fnptsx',['dev_nptsX',['../structPLStream.html#a766da98c5dceb23816632208aa2696b0',1,'PLStream']]],
  ['dev_5fnptsy',['dev_nptsY',['../structPLStream.html#ae2a1837b834853342917152d85a57c41',1,'PLStream']]],
  ['dev_5fswin',['dev_swin',['../structPLStream.html#ab85067bdc3a57afc4a2d3232eebf3b82',1,'PLStream']]],
  ['dev_5ftext',['dev_text',['../structPLStream.html#aa29bb1690b4fe47184b675881d98c272',1,'PLStream']]],
  ['dev_5funicode',['dev_unicode',['../structPLStream.html#a7ab92afcd83164c2633aa13f6056ef46',1,'PLStream']]],
  ['dev_5fx',['dev_x',['../structPLStream.html#a6566af9cc819e25fbbf1cef193ef6696',1,'PLStream']]],
  ['dev_5fxor',['dev_xor',['../structPLStream.html#a88688e6248b7dbdcbcc637b50ff62ec7',1,'PLStream']]],
  ['dev_5fy',['dev_y',['../structPLStream.html#a5442ed8975069a3962d3303fee4dcc2e',1,'PLStream']]],
  ['dev_5fz',['dev_z',['../structPLStream.html#a9c5fe11361bfc214207b1bf769199780',1,'PLStream']]],
  ['dev_5fzmax',['dev_zmax',['../structPLStream.html#aa1ab99774297abc47e0ae0a29b1c62fd',1,'PLStream']]],
  ['dev_5fzmin',['dev_zmin',['../structPLStream.html#a6b267f89557ceef8790911bbb9062bb7',1,'PLStream']]],
  ['devdesc',['devDesc',['../structPlFrame.html#a409578178dbf1cd9bbdf2ce4279503c8',1,'PlFrame::devDesc()'],['../structPlPlotter.html#aaea02031eb53d6fa673b96f19a626a3c',1,'PlPlotter::devDesc()']]],
  ['device',['device',['../structPLStream.html#aba76488f65f93041f7448fee09966b49',1,'PLStream']]],
  ['device_5fheader',['device_header',['../struct__plm__version.html#a4c0e4696f49c6ea945f336f1906b3965',1,'_plm_version']]],
  ['devname',['devName',['../structPlFrame.html#a6bd51c8ea7742c10c24bf57f19a37583',1,'PlFrame::devName()'],['../structPlPlotter.html#a91a6a822d164ae7622b16657567dc372',1,'PlPlotter::devName()'],['../structPLStream.html#aab9c4166d130ca8e402b0b1c5e2539fe',1,'PLStream::DevName()']]],
  ['diclpxma',['diclpxma',['../structPLStream.html#acc943d43125d39d5abdc7b66a53944a9',1,'PLStream']]],
  ['diclpxmi',['diclpxmi',['../structPLStream.html#aedabf7549e134fb86674e4456e3b3313',1,'PLStream']]],
  ['diclpyma',['diclpyma',['../structPLStream.html#a97be1e95c2579b1fc3ed24da73601574',1,'PLStream']]],
  ['diclpymi',['diclpymi',['../structPLStream.html#a0d4efbdb77bab033d72bce77e20c8d15',1,'PLStream']]],
  ['didtests',['didTests',['../aqt_8c.html#a3403bf52b8edb6daa7bfab9a8b034eb2',1,'aqt.c']]],
  ['didxax',['didxax',['../structPLStream.html#ab3ab79d4152a296f7c4f6c091cb77850',1,'PLStream']]],
  ['didxb',['didxb',['../structPLStream.html#acee55fef7a78d2e7da7eec5ab106d29f',1,'PLStream']]],
  ['didyay',['didyay',['../structPLStream.html#a308d6a478bf546f5216399da614540f9',1,'PLStream']]],
  ['didyb',['didyb',['../structPLStream.html#a3f01563d90fa5c2c07a43d03e47e2db5',1,'PLStream']]],
  ['difilt',['difilt',['../structPLStream.html#ac22c7ab738732908f042c0f7f631b505',1,'PLStream']]],
  ['dim',['dim',['../structtclMatrix.html#a6541392bf8e6ecb9d974e9dda856fa95',1,'tclMatrix']]],
  ['dimxax',['dimxax',['../structPLStream.html#ae8d1d27f3d9fc0282c0f0b5b3f233b42',1,'PLStream']]],
  ['dimxb',['dimxb',['../structPLStream.html#a20f7c2bf90e325b365cecd8d2b402847',1,'PLStream']]],
  ['dimxmax',['dimxmax',['../structPLStream.html#a393f3edb7c450ed1d700620bd3c58def',1,'PLStream']]],
  ['dimxmin',['dimxmin',['../structPLStream.html#abbf615b9443c409fd54f64d7a08d11ab',1,'PLStream']]],
  ['dimxpmm',['dimxpmm',['../structPLStream.html#a70512d186177200b25305e4d8613ebe9',1,'PLStream']]],
  ['dimyay',['dimyay',['../structPLStream.html#aaec9ca24b4dc06ac9b0b2fa2ac7dbd8d',1,'PLStream']]],
  ['dimyb',['dimyb',['../structPLStream.html#a74e66a6f996cbe9c004e9845daa94bba',1,'PLStream']]],
  ['dimymax',['dimymax',['../structPLStream.html#ae38a604c5b068a4b46435f2271fe5ea2',1,'PLStream']]],
  ['dimymin',['dimymin',['../structPLStream.html#a64abb742041bd2af0f4c4fb83602b03d',1,'PLStream']]],
  ['dimypmm',['dimypmm',['../structPLStream.html#a815964bc46df8351faefc688044709ed',1,'PLStream']]],
  ['diorot',['diorot',['../structPLStream.html#aff69cf352e07ab556f37a26d19a368fb',1,'PLStream']]],
  ['dioxax',['dioxax',['../structPLStream.html#a001400d3e49aad07d1c89d414b200673',1,'PLStream']]],
  ['dioxay',['dioxay',['../structPLStream.html#a179d0c392cf7a6684e54cb632b6ea225',1,'PLStream']]],
  ['dioxb',['dioxb',['../structPLStream.html#a59ccd7403a647195e073b5764143ff49',1,'PLStream']]],
  ['dioyax',['dioyax',['../structPLStream.html#a3f050b44ba82213a3dc63352ef328770',1,'PLStream']]],
  ['dioyay',['dioyay',['../structPLStream.html#ad05baefb79b865c1324f07e035ecd07d',1,'PLStream']]],
  ['dioyb',['dioyb',['../structPLStream.html#ab459504b6e9f6bb01e8a4f20dafb1a3b',1,'PLStream']]],
  ['dipxax',['dipxax',['../structPLStream.html#a2cecc30bd1ca0277efc230aa1d4c7472',1,'PLStream']]],
  ['dipxb',['dipxb',['../structPLStream.html#a13ef64a5b452b7d4d332379fbdf3ea10',1,'PLStream']]],
  ['dipxmax',['dipxmax',['../structPLStream.html#a4b10cf67465134426a6e0315cda0b5c9',1,'PLStream']]],
  ['dipxmin',['dipxmin',['../structPLStream.html#a99afd44759ce4c50812930c4114379f0',1,'PLStream']]],
  ['dipyay',['dipyay',['../structPLStream.html#afd95befa6c0a9a9793dae9bcb8f7d6fb',1,'PLStream']]],
  ['dipyb',['dipyb',['../structPLStream.html#a475ed8fb0364fba619527d49e0bcd1d8',1,'PLStream']]],
  ['dipymax',['dipymax',['../structPLStream.html#a04323978cc4239d9dc14fc046242af7e',1,'PLStream']]],
  ['dipymin',['dipymin',['../structPLStream.html#aa8af982530bc17c9ff924805c3c01aad',1,'PLStream']]],
  ['director',['director',['../structswig__octave__class.html#af6c5e0b035923e4489939936e82fa15c',1,'swig_octave_class']]],
  ['dispatch_5ftable',['dispatch_table',['../structPLStream.html#a887a3e2a4b6fa529050419fddea30a77',1,'PLStream::dispatch_table()'],['../plcore_8h.html#a57e441fc18d6c70aa946cb3f31363099',1,'dispatch_table():&#160;plcore.h']]],
  ['display',['display',['../structPlFrame.html#aade49f122a5252b45ab7f0a54824314c',1,'PlFrame::display()'],['../structPlPlotter.html#aba63a469923ac91734ef6521bf3a96da',1,'PlPlotter::display()'],['../structTkwDisplay.html#a13d5ba6d124870de4d2c9cb56d9fe27d',1,'TkwDisplay::display()'],['../structXwDisplay.html#aed2b77a9ad5f7acdeb35637df3bdf591',1,'XwDisplay::display()'],['../tkMain_8c.html#ac673895cdd4a06409b42c362bc4ff0d2',1,'display():&#160;tkMain.c']]],
  ['displayname',['displayName',['../structTkwDisplay.html#a1779b68c9b97e7be0116c5640f81dca7',1,'TkwDisplay::displayName()'],['../structXwDisplay.html#ae540a35000de9cbebd7c2ba40fb86ca8',1,'XwDisplay::displayName()']]],
  ['dist',['dist',['../structpt.html#a1c68de66b27b10580e7305bade7cd541',1,'pt']]],
  ['div',['div',['../structplf2ops__t.html#adee8c7c790b5b49672909c53f505a5d4',1,'plf2ops_t']]],
  ['doc',['doc',['../structswig__octave__member.html#a9d331d2028fa0141e9fb9824dfe48b9b',1,'swig_octave_member']]],
  ['domxma',['domxma',['../structPLStream.html#a4c6dedc71895250e9ca0d1c06ff8332d',1,'PLStream']]],
  ['domxmi',['domxmi',['../structPLStream.html#ac067cc75f47a42d588dc74194e0e0bc7',1,'PLStream']]],
  ['domyma',['domyma',['../structPLStream.html#a1a4d3ea4f87b7421f8e74f58c98ea866',1,'PLStream']]],
  ['domymi',['domymi',['../structPLStream.html#a5e0d0b52d8a39bceaca339e1d6f1396e',1,'PLStream']]],
  ['double_5fbuffer',['double_buffer',['../structPlPlotter.html#a2dc979e3e11b78f99df3329c82f21b78',1,'PlPlotter']]],
  ['downscale',['downscale',['../structPLCairo.html#a7210324a6b46a828bc114f3e605cc784',1,'PLCairo::downscale()'],['../classQtPLDriver.html#a05e234498832892294d6a0bed2fcae6e',1,'QtPLDriver::downscale()']]],
  ['dp',['dp',['../structPLStream.html#add8acf85b1d1d1800c8eb7df0535c400',1,'PLStream']]],
  ['draw_5flinex',['DRAW_LINEX',['../classplplot.html#a53c151ff9300048429b05568946f4b58',1,'plplot::DRAW_LINEX()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a78186e922b4c0587058b89df782d5ead',1,'plplot.core.plplotjavacConstants.DRAW_LINEX()'],['../namespaceplplotc.html#a1468d03369594fe90e8eb5cc464a859b',1,'plplotc.DRAW_LINEX()']]],
  ['draw_5flinexy',['DRAW_LINEXY',['../classplplot.html#ab4fc454297b7b4df3c1f73fe9dae4cbe',1,'plplot::DRAW_LINEXY()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a6b221b57c0b722bcca7d18195666d5fb',1,'plplot.core.plplotjavacConstants.DRAW_LINEXY()'],['../namespaceplplotc.html#ac51a99e6a9f091db6f2996d97f675fd6',1,'plplotc.DRAW_LINEXY()']]],
  ['draw_5fliney',['DRAW_LINEY',['../classplplot.html#aa566c9a8b5967e071359585fbbe5975e',1,'plplot::DRAW_LINEY()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a57935553f9eed159d7071c06cdf27e18',1,'plplot.core.plplotjavacConstants.DRAW_LINEY()'],['../namespaceplplotc.html#ae85623e8a7f98f87cf65876928d75951',1,'plplotc.DRAW_LINEY()']]],
  ['draw_5fsides',['DRAW_SIDES',['../classplplot.html#a498074676eb148d19d7465505e44ae2c',1,'plplot::DRAW_SIDES()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a1045c9467abda926a1710b7103962e9b',1,'plplot.core.plplotjavacConstants.DRAW_SIDES()'],['../namespaceplplotc.html#a666c56f6d51ce51bd51c15bde0834f75',1,'plplotc.DRAW_SIDES()']]],
  ['drawing_5frband',['drawing_rband',['../structPlFrame.html#adf4ddc0c44164d8a0d5bdfa3e0878aef',1,'PlFrame::drawing_rband()'],['../structPlPlotter.html#a153b99d69175b18f0691cc1d0d593c4e',1,'PlPlotter::drawing_rband()']]],
  ['drawing_5fxhairs',['drawing_xhairs',['../structPlFrame.html#a983f748494f81aecc7bd02ad139b168c',1,'PlFrame::drawing_xhairs()'],['../structPlPlotter.html#af10abb0cf0b1266ccdf1641e6551b2af',1,'PlPlotter::drawing_xhairs()'],['../structTkwDev.html#a3e454f604d96880ce717313096bc51c6',1,'TkwDev::drawing_xhairs()'],['../structXwDev.html#a9a6b2d42496aa00b41eac624b8b70101',1,'XwDev::drawing_xhairs()']]],
  ['drv_5fopt',['drv_opt',['../plargs_8c.html#ad42924d347ff680f9d8e7eb36415f079',1,'plargs.c']]],
  ['dum_5fuchar',['dum_uchar',['../plr_8c.html#ae41f387fd9b07755f1b68ea2b834786f',1,'plr.c']]],
  ['dum_5fushort',['dum_ushort',['../plr_8c.html#a7379e9a3346908d1d9c0eac320a065f4',1,'plr.c']]],
  ['dvalue',['dvalue',['../structswig__lua__const__info.html#ac50e848b2a6a628fa1eeb4924f608cee',1,'swig_lua_const_info::dvalue()'],['../structswig__const__info.html#a74e477f1dbf515bcb7e2ef07a1d34c35',1,'swig_const_info::dvalue()']]],
  ['dx',['dx',['../structplplot__graphics_1_1plgraphicsin.html#ac3f083e4645ed568195d759a57fb6816',1,'plplot_graphics::plgraphicsin::dx()'],['../structIMG__DT.html#a96c130e4360f7780f2d161c0a3f32108',1,'IMG_DT::dx()'],['../structplplot_1_1__N2.html#ac646480593d84982db2b8e860117d475',1,'plplot::_N2::dX()'],['../structPLGraphicsIn.html#ae15d582003fed123c0d48d422bffd144',1,'PLGraphicsIn::dX()'],['../namespacePlframe.html#a2def17e5a9cb1392e4f4fa30fd6de33e',1,'Plframe.dx()']]],
  ['dxma',['dxma',['../structplplot_1_1__N3.html#a5fa61330c619cd69264439d602c5efd2',1,'plplot::_N3::dxma()'],['../structPLWindow.html#aa7846632259bd8ddb2cf695b4112232a',1,'PLWindow::dxma()']]],
  ['dxmi',['dxmi',['../structplplot_1_1__N3.html#aefe9237accf83fb06db55ab6a10e7ee8',1,'plplot::_N3::dxmi()'],['../structPLWindow.html#afa3570309e945c264e79ba2a3a566fec',1,'PLWindow::dxmi()']]],
  ['dy',['dy',['../structplplot__graphics_1_1plgraphicsin.html#ad029a91a4f2d101ea0c7d428762eae5e',1,'plplot_graphics::plgraphicsin::dy()'],['../structIMG__DT.html#a18206f1e64d54e345fcde39d067e6ad7',1,'IMG_DT::dy()'],['../structplplot_1_1__N2.html#ae6c62648845e3d0ba49ea02faabc4127',1,'plplot::_N2::dY()'],['../structPLGraphicsIn.html#a90a08dfcb5e486ac4ce34507a6004c11',1,'PLGraphicsIn::dY()'],['../namespacePlframe.html#a392c52a1b0b0b952bb2a7fada883e13a',1,'Plframe.dy()']]],
  ['dyma',['dyma',['../structplplot_1_1__N3.html#a8c0d51fd26029f65910eb9473627381c',1,'plplot::_N3::dyma()'],['../structPLWindow.html#a4d0b980695e01367e50079521e61fc24',1,'PLWindow::dyma()']]],
  ['dymi',['dymi',['../structplplot_1_1__N3.html#af0e5799d84888b318e2995e04ea8d1a8',1,'plplot::_N3::dymi()'],['../structPLWindow.html#ac5a88aaabbd32564239f8a3f62f8892b',1,'PLWindow::dymi()']]]
];
